@@ -1,5 +1,5 @@
 /* Hey EMACS -*- linux-c -*- */
-/* $Id: ti85.c 733 2004-05-28 21:11:48Z roms $ */
+/* $Id: ti85.c 970 2005-04-24 09:41:50Z roms $ */
 
 /*  libticalcs - Ti Calculator library, a part of the TiLP project
  *  Copyright (C) 1999-2004  Romain Lievin
@@ -378,6 +378,11 @@ int ti85_send_var(const char *filename, int mask_mode)
   return 0;
 }
 
+int ti85_recv_var_2(char *filename, int mask_mode, TiVarEntry * entry)
+{
+	return ERR_VOID_FUNCTION;
+}
+
 int ti85_send_flash(const char *filename, int mask_mode)
 {
   return ERR_VOID_FUNCTION;
