@@ -1,8 +1,9 @@
 /* Hey EMACS -*- linux-c -*- */
-/* $Id: ti89.c 860 2005-02-24 12:25:52Z roms $ */
+/* $Id: ti89.c 985 2005-04-27 21:11:08Z roms $ */
 
 /*  libticalcs - Ti Calculator library, a part of the TiLP project
- *  Copyright (C) 1999-2004  Romain Lievin
+ *  Copyright (C) 1999-2005  Romain Lievin
+ *  Copyright (c) 2005, Christian Walther (patches for Mac OS-X port)
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -547,6 +548,98 @@ int ti89_send_var(const char *filename, int mask_mode, char **actions)
   return 0;
 }
 
+// automatically build filename and put it into 'filename'.
+// mask_mode is unused
+// 'entry' contains informations
+int ti89_recv_var_2(char *filename, int mask_mode, TiVarEntry * entry)
+{
+	Ti9xRegular *content;
+	uint32_t unused;
+	uint8_t utf8[35];
+	int nvar, err;
+    char tipath[18];
+    char *tiname;
+
+	printl2(0, _("Receiving variable(s)...\n"));
+
+	// open cable
+	LOCK_TRANSFER();
+	TRYF(cable->open());
+	update_start();
+
+	// create variable content and fills
+    content = ti9x_create_regular_content();
+	content->calc_type = ticalcs_calc_type;
+
+	// receive packets
+	for(nvar = 1;; nvar++)
+	{
+		TiVarEntry *ve;
+
+		content->entries = (TiVarEntry *) tifiles_realloc(content->entries, nvar * sizeof(TiVarEntry));
+		ve = &(content->entries[nvar-1]);
+		strcpy(ve->folder, "main");	
+
+		err = ti89_recv_VAR(&ve->size, &ve->type, tipath);
+		TRYF(ti89_send_ACK());
+
+		if(err == ERR_EOT)	// end of transmission
+			goto exit;
+		else
+			content->num_entries = nvar;
+
+		// from Christian (TI can send varname or fldname/varname)
+        if ((tiname = strchr(tipath, '\\')) != NULL) 
+		{
+			*tiname = '\0';
+            strcpy(ve->folder, tipath);
+            strcpy(ve->name, tiname + 1);
+        }
+        else 
+		{
+            strcpy(ve->folder, "main");
+            strcpy(ve->name, tipath);
+        }
+
+		tifiles_translate_varname(ve->name, utf8, ve->type);
+		sprintf(update->label_text, _("Receiving '%s'"), utf8);
+		update_label();
+
+		TRYF(ti89_send_CTS());
+		TRYF(ti89_recv_ACK(NULL));
+
+		ve->data = tifiles_calloc(ve->size + 4, 1);
+		TRYF(ti89_recv_XDP(&unused, ve->data));
+		memmove(ve->data, ve->data + 4, ve->size);
+		TRYF(ti89_send_ACK());
+	}
+
+exit:
+	// close cable
+	TRYF(cable->close());
+	UNLOCK_TRANSFER();
+    
+	// write file content
+	nvar--;
+	if(nvar > 1)
+	{
+		strcpy(content->comment, "Group file received by TiLP");
+		strcat(filename, "group.92g");
+		ti9x_write_regular_file(filename, content, NULL);
+	}
+	else
+	{
+		strcpy(content->comment, "Single file received by TiLP");
+		strcat(filename, content->entries[0].name);
+		strcat(filename, ".");
+		strcat(filename, tifiles_vartype2file(content->entries[0].type));
+		ti9x_write_regular_file(filename, content, NULL);
+	}
+    ti9x_free_regular_content(content);
+
+	return 0;
+}
+
 int ti89_send_flash(const char *filename, int mask_mode)
 {
   Ti9xFlash content = { 0 };
